@@ -32,15 +32,19 @@ def insertrow():
 
 def select():
     parser = argparse.ArgumentParser(prog ='badsql',
-                                     description ='badsql insertrow')
+                                     description ='badsql select')
     parser.add_argument('query', metavar ='query', type=str, nargs=1, help= 'query')
 
+    parser.add_argument('save', metavar ='save', type=bool, nargs=1, default=False, help= 'save')
+
     args = parser.parse_args()
 
     try:
         db = badsql.load('test')
         new_db = db.select(args.query[0])
         new_db.display()
+        if args.save[0]:
+            new_db.save('test')
     except Exception as e:
         print('Error occurred:', e)
 
@@ -49,3 +53,17 @@ def display():
         badsql.load('test').display()
     except Exception as e:
         print('Error occurred:', e)
+
+def removerow():
+    parser = argparse.ArgumentParser(prog ='badsql',
+                                     description ='badsql removerow')
+
+    parser.add_argument('pos', metavar ='pos', type=int, nargs=1, help= 'pos')
+
+    args = parser.parse_args()
+
+    try:
+        db = badsql.load('test')
+        db.delete(args.pos[0])
+        db.display()
+        db.save('test')
